#!/bin/perl -w
#################################################################################
# Created       : Martin Foster
# Modified      : 02-Jul-2003
#################################################################################
#
# Convert - Will massage dump files accordingly can be used in a pipe
# Copyright (C) 2000-2004  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 29-26503 TWP RD 511
#                 Spruce Grove, Alberta
#                 T7Y 1G4
#
#################################################################################

#################################################################################
# Data Members
#################################################################################

my $line;						# Selected line
my $iso;						# Formatted timestamp


#################################################################################
# Program Area
#################################################################################

	# Loop and process
	# Capture line
	while ($line = <STDIN>)
	{
		# Skips
		next if ($line =~ /^--/);
		next if ($line =~ /^\n/);

		# Insertion string
		$line =~ s/INSERT\sINTO\s(\w+)\s/INSERT INTO ethereal.$1 /gs;

		# Timestamps
		# Locate
		while ($line =~ /(\d{9,10})/gs)
		{
			# Convert
			$iso = GetISO($1);

			# Replace
			$line =~ s/$1/$iso/gs;
		}

		# Display
		print "$line";
	}


#################################################################################
# Sub-Routines
#################################################################################

#####################
# GetISO
#
# Returns an ISO formatted date/time stamp used in database creation.   This
# is in turn used to replace Unix time.

sub GetISO
{
	#####################
	# Data members
	my $time = shift;					# Time


	#####################
	# Program area

	# Retreive time
	my ($sec, $min, $hour, $mday, $mon, $year) = localtime($time);

	# Massage values
	$sec  = ($sec    < 10) ? "0$sec"  : $sec;
	$min  = ($min    < 10) ? "0$min"  : $min;
	$hour = ($hour   < 10) ? "0$hour" : $hour;
	$mday = ($mday   < 10) ? "0$mday" : $mday;
	$mon  = (++$mon  < 10) ? "0$mon"  : $mon;

	# Handle year
	$year += 1900;

	# Return appropriate value
	return "\'${year}-${mon}-${mday} ${hour}:${min}:${sec}\'";
}
