#################################################################################
# Created       : Martin Foster
# Modified      : 12-Sep-2003
#################################################################################
#
# Proto - Script that will create useful database dumps.
# Copyright (C) 2000-2004  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 29-26503 TWP RD 511
#                 Spruce Grove, Alberta
#                 T7Y 1G4
#
#################################################################################

use strict;							# Strict variable enforcement
use File::Copy;							# File copy handle

#################################################################################
# Data Members
#################################################################################

#
# Change as needed
#
my $path = 'CHANGE';						# Location of ER files
my $perl = 'CHANGE';						# Location of Perl executable
my $libs = 'CHANGE';						# Location of ER libs


#
# Static
#
my $head = '#!/bin/perl';					# Location of existing header


#################################################################################
# Program Area
#################################################################################

	# Initial display
	print "File rewriting in progress....\n";

	# Initial call
	DirHandle($path);

	# Signal completion
	print "Done!\n";


#################################################################################
# Sub-Routines
#################################################################################

#####################
# Directory Manage
#
# Will look at a given directory and see what is available to be modified.  In
# addition, it will recursively call sub-directories as to handle those as well.

sub DirHandle
{
	#####################
	# Data members

	my $dir      = shift;					# Directory name
	my $file;						# File name

	my @locales;						# Additional directories

	#####################
	# Program area

	# Inform users
	print " Working on directory: $dir\n";

	# Open Directory Handle
	opendir(DIR, "$dir/")
	 or die("Program was unable to open directory $dir: $!");

	# Read through directory listing
	while ($file = readdir(DIR))
	{
		# Skip parent and current
		next if ($file eq '.');
		next if ($file eq '..');

		# Directory
		if (-d "$dir/$file")
		{
			# Add to list
			push(@locales, "$dir/$file");
		}

		# File
		elsif (-f "$dir/$file")
		{
			# Rewrite file if necessary
			FileMod("$dir/$file");
		}
	}

	# Close directory
	closedir(DIR);


	# Call additional directories
	foreach $dir (sort(@locales))
	{
		# Handle subdirectory
		DirHandle($dir);
	}
}


#####################
# File Modify
#
# Will change a file if necessary, the first step being that it will verify
# that the appropriate header exists and then change the file as needed.

sub FileMod
{
	#####################
	# Data members

	my $file     = shift;					# Filename

	my $count    = 0;					# Counter
	my $line;						# Singlular line


	#####################
	# Program area

	# Open input file handle
	open(INPUT, "<$file")
	 or die ("Unable to open file $file for reading: $!");


	# Loop through file
	while ($line = <INPUT>)
	{
		# Initial check
		if ($count < 1)
		{
			# Confirm the appropriate file exists
			unless ($line =~ /^$head/si)
			{
				# Display error
				print "  Skipping: $file\n";	

				# Close file
				close(INPUT);

				# Exit loop
				last;
			}

			# Prepare for rewrite
			else
			{
				# Display change
				print "  Changing: $file";	

				# Open output file handle
				open(OUTPUT, ">$file.new")
				 or die ("Unable to open file $file for writing: $!");

				# Print initial lines
				print OUTPUT "#!$perl\n";
				print OUTPUT "use lib '$libs';\n\n"
			}
		}

		# Remaining lines
		else
		{
			# Add in additional lines
			print OUTPUT $line;
		}

		# Increment
		$count++;
	}

	# Post input
	if ($count > 0)
	{
		# Close files
		close(INPUT);
		close(OUTPUT);

		# Status display
		print ".";

		# Remove old file
		unlink("$file")
		  or die("Unable to remove orginal file $file: $!");


		# Status display
		print ".";

		# Rename file
		rename("$file.new", "$file");


		# Display file
		print "done!\n";
	}
}
